# -*- coding: utf-8 -*-
import abc
import json
import pprint

import yaml
from tencentcloud.common import credential
from tencentcloud.common.exception.tencent_cloud_sdk_exception import \
    TencentCloudSDKException
from tencentcloud.common.profile.client_profile import ClientProfile
from tencentcloud.common.profile.http_profile import HttpProfile
from tencentcloud.monitor.v20180724 import models, monitor_client

from conf import config

class Tencent(object):
    def __init__(self):
        self.secret_id = config['tencent_settings']['secret_id']
        self.secret_key = config['tencent_settings']['secret_key']
        self.cred = credential.Credential(self.secret_id, self.secret_key)

    @abc.abstractmethod
    def _get_client(self):
        """ get client
        """

    def json_format(self, response):
        if isinstance(response, bytes):
            response = response.decode()
        return json.loads(response)


class Monitor(Tencent):
    def __init__(self, region="ap-beijing", endpoint="monitor.tencentcloudapi.com"):
        super(Monitor, self).__init__()
        self.client = self._get_client(region, endpoint)

    def _get_client(self, region, endpoint):
        httpProfile = HttpProfile()
        httpProfile.endpoint = endpoint
        clientProfile = ClientProfile()
        clientProfile.httpProfile = httpProfile
        client = monitor_client.MonitorClient(self.cred, region, clientProfile)
        return client

    def _describe_base_metrics(self, params_dict):
        assert isinstance(params_dict, dict)
        req = models.DescribeBaseMetricsRequest()
        req.from_json_string(json.dumps(params_dict))
        resp = self.client.DescribeBaseMetrics(req)
        return self.json_format(resp.to_json_string())

    def _get_monitor_data(self, params_dict):
        assert isinstance(params_dict, dict)
        req = models.GetMonitorDataRequest()
        req.from_json_string(json.dumps(params_dict))
        resp = self.client.GetMonitorData(req)
        return self.json_format(resp.to_json_string())

    def get_cdb_metric(self, instance_id_list, metric, duration=60*6):
        params_dict = {
            "Namespace": "QCE/CDB",
            "MetricName": metric,
            "Period": 5,
            "Instances": [
                {
                    "Dimensions": [
                        {
                            "Name": "InstanceId",
                            "Value": instance_id
                        }
                    ]
                } for instance_id in instance_id_list
            ],
            "StartTime": "2019-04-02T12:30:00+08:00",
            "EndTime": "2019-04-02T12:35:00+08:00"
        }
        resp = self._get_monitor_data(params_dict)
        return resp
